# modules here
def run():
    import pyinstaller_dump
    pyinstaller_dump.run()


if __name__ == '__main__':
    run()
